"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from eis.customers.api_client import ApiClient, Endpoint as _Endpoint
from eis.customers.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from eis.customers.model.complete_payment_setup_psp_request import CompletePaymentSetupPspRequest
from eis.customers.model.complete_payment_setup_response_class import CompletePaymentSetupResponseClass
from eis.customers.model.initiate_payment_setup_response_class import InitiatePaymentSetupResponseClass


class PaymentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.complete_payment_setup_endpoint = _Endpoint(
            settings={
                'response_type': (CompletePaymentSetupResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/payment_setup/complete',
                'operation_id': 'complete_payment_setup',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'complete_payment_setup_psp_request',
                    'authorization',
                ],
                'required': [
                    'customer_code',
                    'complete_payment_setup_psp_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'complete_payment_setup_psp_request':
                        (CompletePaymentSetupPspRequest,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'complete_payment_setup_psp_request': 'body',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.initiate_payment_setup_endpoint = _Endpoint(
            settings={
                'response_type': (InitiatePaymentSetupResponseClass,),
                'auth': [],
                'endpoint_path': '/v1/customers/{customerCode}/payment_setup/initiate',
                'operation_id': 'initiate_payment_setup',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'customer_code',
                    'authorization',
                ],
                'required': [
                    'customer_code',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'customer_code':
                        (str,),
                    'authorization':
                        (str,),
                },
                'attribute_map': {
                    'customer_code': 'customerCode',
                    'authorization': 'Authorization',
                },
                'location_map': {
                    'customer_code': 'path',
                    'authorization': 'header',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def complete_payment_setup(
        self,
        customer_code,
        complete_payment_setup_psp_request,
        **kwargs
    ):
        """Request payment setup complete  # noqa: E501

        Request to complete a payment change by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.complete_payment_setup(customer_code, complete_payment_setup_psp_request, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.
            complete_payment_setup_psp_request (CompletePaymentSetupPspRequest):

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CompletePaymentSetupResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        kwargs['complete_payment_setup_psp_request'] = \
            complete_payment_setup_psp_request
        return self.complete_payment_setup_endpoint.call_with_http_info(**kwargs)

    def initiate_payment_setup(
        self,
        customer_code,
        **kwargs
    ):
        """Request payment setup initiation  # noqa: E501

        Request to initiate a payment change by customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.initiate_payment_setup(customer_code, async_req=True)
        >>> result = thread.get()

        Args:
            customer_code (str): The customer code or \"me\" for the currently logged in customer.

        Keyword Args:
            authorization (str): Bearer Token: provided by the login endpoint under the name accessToken.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            InitiatePaymentSetupResponseClass
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['customer_code'] = \
            customer_code
        return self.initiate_payment_setup_endpoint.call_with_http_info(**kwargs)

