"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.claims_api import ClaimsApi  # noqa: E501


class TestClaimsApi(unittest.TestCase):
    """ClaimsApi unit test stubs"""

    def setUp(self):
        self.api = ClaimsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer_claim(self):
        """Test case for create_customer_claim

        Create a new claim  # noqa: E501
        """
        pass

    def test_get_customer_claim(self):
        """Test case for get_customer_claim

        Get claim  # noqa: E501
        """
        pass

    def test_list_customer_claims(self):
        """Test case for list_customer_claims

        List claims  # noqa: E501
        """
        pass

    def test_update_customer_claim(self):
        """Test case for update_customer_claim

        Update claim  # noqa: E501
        """
        pass

    def test_upload_customer_claim_documents(self):
        """Test case for upload_customer_claim_documents

        Upload claim documents  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
