"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forgot_password(self):
        """Test case for forgot_password

        Forgot password by customer  # noqa: E501
        """
        pass

    def test_initiate_auth(self):
        """Test case for initiate_auth

        Initiate auth by customer  # noqa: E501
        """
        pass

    def test_refresh_token(self):
        """Test case for refresh_token

        Refresh token by customer  # noqa: E501
        """
        pass

    def test_reset_password(self):
        """Test case for reset_password

        Change password by customer  # noqa: E501
        """
        pass

    def test_respond_to_auth_challenge(self):
        """Test case for respond_to_auth_challenge

        Respond to auth challenge  # noqa: E501
        """
        pass

    def test_verify_reset_password_token(self):
        """Test case for verify_reset_password_token

        Verify a reset password token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
