"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.customers_api import CustomersApi  # noqa: E501


class TestCustomersApi(unittest.TestCase):
    """CustomersApi unit test stubs"""

    def setUp(self):
        self.api = CustomersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customer(self):
        """Test case for get_customer

        Get customer details  # noqa: E501
        """
        pass

    def test_list_customers(self):
        """Test case for list_customers

        Get customers list  # noqa: E501
        """
        pass

    def test_update_customer(self):
        """Test case for update_customer

        Update customer details  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
