"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.create_account_request_dto import CreateAccountRequestDto
from eis.customers.model.create_payment_method_request_dto import CreatePaymentMethodRequestDto
from eis.customers.model.create_policy_request_dto import CreatePolicyRequestDto
from eis.customers.model.invoice_class import InvoiceClass
from eis.customers.model.lead_bank_account_class import LeadBankAccountClass
from eis.customers.model.premium_override_request_class import PremiumOverrideRequestClass
from eis.customers.model.uploaded_document_dto import UploadedDocumentDto
globals()['CreateAccountRequestDto'] = CreateAccountRequestDto
globals()['CreatePaymentMethodRequestDto'] = CreatePaymentMethodRequestDto
globals()['CreatePolicyRequestDto'] = CreatePolicyRequestDto
globals()['InvoiceClass'] = InvoiceClass
globals()['LeadBankAccountClass'] = LeadBankAccountClass
globals()['PremiumOverrideRequestClass'] = PremiumOverrideRequestClass
globals()['UploadedDocumentDto'] = UploadedDocumentDto
from eis.customers.model.lead_class import LeadClass


class TestLeadClass(unittest.TestCase):
    """LeadClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLeadClass(self):
        """Test LeadClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = LeadClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
