"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.create_bank_account_request_dto import CreateBankAccountRequestDto


class TestCreateBankAccountRequestDto(unittest.TestCase):
    """CreateBankAccountRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateBankAccountRequestDto(self):
        """Test CreateBankAccountRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateBankAccountRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
