"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.initiate_stripe_payment_setup_response_class import InitiateStripePaymentSetupResponseClass


class TestInitiateStripePaymentSetupResponseClass(unittest.TestCase):
    """InitiateStripePaymentSetupResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInitiateStripePaymentSetupResponseClass(self):
        """Test InitiateStripePaymentSetupResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InitiateStripePaymentSetupResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
