"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.policy_object_class import PolicyObjectClass
from eis.customers.model.policy_premium_class import PolicyPremiumClass
globals()['PolicyObjectClass'] = PolicyObjectClass
globals()['PolicyPremiumClass'] = PolicyPremiumClass
from eis.customers.model.timeslice_class import TimesliceClass


class TestTimesliceClass(unittest.TestCase):
    """TimesliceClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTimesliceClass(self):
        """Test TimesliceClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TimesliceClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
