"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.customer_product_class import CustomerProductClass
globals()['CustomerProductClass'] = CustomerProductClass
from eis.customers.model.list_products_response_class import ListProductsResponseClass


class TestListProductsResponseClass(unittest.TestCase):
    """ListProductsResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListProductsResponseClass(self):
        """Test ListProductsResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListProductsResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
