"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.policies_api import PoliciesApi  # noqa: E501


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self):
        self.api = PoliciesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customer_policy_data_by_date(self):
        """Test case for get_customer_policy_data_by_date

        Get current version details  # noqa: E501
        """
        pass

    def test_get_policy(self):
        """Test case for get_policy

        Get policy details  # noqa: E501
        """
        pass

    def test_list_policies(self):
        """Test case for list_policies

        List policies  # noqa: E501
        """
        pass

    def test_request_policy_update(self):
        """Test case for request_policy_update

        Request policy update  # noqa: E501
        """
        pass

    def test_terminate_customer_policy(self):
        """Test case for terminate_customer_policy

        Terminate a policy  # noqa: E501
        """
        pass

    def test_upload_customer_policy_documents(self):
        """Test case for upload_customer_policy_documents

        Upload policy documents  # noqa: E501
        """
        pass

    def test_withdraw_customer_policy(self):
        """Test case for withdraw_customer_policy

        Withdraw the policy  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
