"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.leads_api import LeadsApi  # noqa: E501


class TestLeadsApi(unittest.TestCase):
    """LeadsApi unit test stubs"""

    def setUp(self):
        self.api = LeadsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_lead(self):
        """Test case for create_lead

        Create the lead  # noqa: E501
        """
        pass

    def test_get_lead(self):
        """Test case for get_lead

        Retrieve the lead  # noqa: E501
        """
        pass

    def test_list_leads(self):
        """Test case for list_leads

        List leads  # noqa: E501
        """
        pass

    def test_update_lead(self):
        """Test case for update_lead

        Update the lead  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
