"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.customers
from eis.customers.model.create_bank_account_request_dto import CreateBankAccountRequestDto
from eis.customers.model.create_payment_method_request_dto import CreatePaymentMethodRequestDto
from eis.customers.model.policy_object_dto import PolicyObjectDto
from eis.customers.model.premium_override_request_dto import PremiumOverrideRequestDto
from eis.customers.model.uploaded_document_dto import UploadedDocumentDto
globals()['CreateBankAccountRequestDto'] = CreateBankAccountRequestDto
globals()['CreatePaymentMethodRequestDto'] = CreatePaymentMethodRequestDto
globals()['PolicyObjectDto'] = PolicyObjectDto
globals()['PremiumOverrideRequestDto'] = PremiumOverrideRequestDto
globals()['UploadedDocumentDto'] = UploadedDocumentDto
from eis.customers.model.create_lead_request_dto import CreateLeadRequestDto


class TestCreateLeadRequestDto(unittest.TestCase):
    """CreateLeadRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateLeadRequestDto(self):
        """Test CreateLeadRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateLeadRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
