"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.documents_api import DocumentsApi  # noqa: E501


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_customer_document_download_url(self):
        """Test case for get_customer_document_download_url

        Get a download url for document  # noqa: E501
        """
        pass

    def test_list_documents(self):
        """Test case for list_documents

        List documents of a customer  # noqa: E501
        """
        pass

    def test_upload_account_documents(self):
        """Test case for upload_account_documents

        Upload account documents  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
