"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.payments_api import PaymentsApi  # noqa: E501


class TestPaymentsApi(unittest.TestCase):
    """PaymentsApi unit test stubs"""

    def setUp(self):
        self.api = PaymentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_payment_setup(self):
        """Test case for complete_payment_setup

        Request payment setup complete  # noqa: E501
        """
        pass

    def test_initiate_payment_setup(self):
        """Test case for initiate_payment_setup

        Request payment setup initiation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
