"""
    EMIL CustomerService

    The EMIL CustomerService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.customers
from eis.customers.api.invites_api import InvitesApi  # noqa: E501


class TestInvitesApi(unittest.TestCase):
    """InvitesApi unit test stubs"""

    def setUp(self):
        self.api = InvitesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_customer(self):
        """Test case for create_customer

        Register a customer after invite  # noqa: E501
        """
        pass

    def test_invite_by_customer(self):
        """Test case for invite_by_customer

        Invite a customer by self  # noqa: E501
        """
        pass

    def test_invite_by_tenant(self):
        """Test case for invite_by_tenant

        Invite a customer by tenant  # noqa: E501
        """
        pass

    def test_verify_invite(self):
        """Test case for verify_invite

        Verify customer's invite token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
